Fix eval sign bug in (not-yet-used) null move
[hachu.git] / hachu.c
diff --git a/hachu.c b/hachu.c
index ca7f32d..87b227f 100644 (file)
--- a/hachu.c
+++ b/hachu.c
@@ -1523,7 +1523,7 @@ if(PATH) /*pboard(board),pmap(attacks, BLACK),*/printf("search(%d) {%d,%d} eval=
   nodes++;\r
   pv[pvPtr++] = 0; // start empty PV, directly behind PV of parent\r
 \r
-  firstMove = curMove = sorted = msp += 20; // leave 20 empty slots in front of move list\r
+  firstMove = curMove = sorted = msp += 50; // leave 50 empty slots in front of move list\r
   tb.fireMask = phase = 0; iterDep=1; replyDep = (depth < 1 ? depth : 1) - 1;\r
   do {\r
 if(flag && depth>= 0) printf("iter %d:%d\n", depth,iterDep),fflush(stdout);\r
@@ -1541,7 +1541,7 @@ if(flag && depth>= 0) printf("phase=%d: first/curr/last = %d / %d / %d\n", phase
 #if 0\r
            if(curEval >= beta) {\r
              stm ^= WHITE;\r
-             score = -Search(-beta, -iterAlpha, difEval, depth-3, promoSuppress & SQUARE, ABSENT);\r
+             score = -Search(-beta, -iterAlpha, -difEval, depth-3, promoSuppress & SQUARE, ABSENT);\r
              stm ^= WHITE;\r
              if(score >= beta) { msp = oldMSP; retDep += 3; return score + (score < curEval); }\r
            }\r